#
# spec file for package libjpeg62-turbo
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define major   62
%define minor   1
%define micro   0
%define srcver  1.3.1
%define libver  %{major}.%{minor}.%{micro}

Name:           libjpeg62-turbo
Version:        %{srcver}
Release:        32.3
Summary:        A MMX/SSE2 accelerated library for manipulating JPEG image files
License:        BSD-3-Clause
Group:          Productivity/Graphics/Convertors
Url:            http://sourceforge.net/projects/libjpeg-turbo
Source0:        http://downloads.sourceforge.net/project/libjpeg-turbo/%{version}/libjpeg-turbo-%{version}.tar.gz
Source1:        baselibs.conf
Patch0:         libjpeg-turbo-1.3.0-int32.patch
Patch1:         libjpeg-turbo-1.3.0-tiff-ojpeg.patch
Patch2:         libjpeg-ocloexec.patch
Patch3:         libjpeg-turbo-CVE-2014-9092.patch
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  yasm
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Conflicts:      jpeg%{major}

%description
The libjpeg-turbo package contains a library of functions for manipulating
JPEG images.

%package -n libjpeg%{major}

Version:        %{libver}
Release:        32.3
Summary:        The MMX/SSE accelerated JPEG compression/decompression library
Group:          System/Libraries
Provides:       libjpeg%{major} = %{version}
Obsoletes:      libjpeg%{major} < %{version}
# bug437293
%ifarch ppc64
Obsoletes:      libjpeg-64bit < %{version}
%endif
#

%description -n libjpeg%{major}
This library contains MMX/SSE accelerated functions for manipulating
JPEG images.

%package -n libjpeg%{major}-devel
Version:        %{libver}
Release:        32.3
Summary:        Development Tools for applications which will use the Libjpeg Library
Group:          Development/Libraries/C and C++
Requires:       libjpeg%{major} = %{version}
Provides:       libjpeg-devel = %{version}
Obsoletes:      libjpeg-devel < %{version}
Conflicts:      otherproviders(libjpeg-devel)
# bug437293
%ifarch ppc64
Obsoletes:      libjpeg-devel-64bit < %{version}
%endif
#

%description -n libjpeg%{major}-devel
The libjpeg-devel package includes the header files and libraries
necessary for compiling and linking programs which will manipulate JPEG
files using the libjpeg library.

%prep
%setup -q -n libjpeg-turbo-%{srcver}
%patch0
%patch1
%patch2
%patch3

%build
autoreconf -fiv
export LDFLAGS="-Wl,-z,relro,-z,now"
%configure --disable-static 
make %{?_smp_mflags}

%check
make test libdir=%{_libdir}

%install
%makeinstall
# Fix perms
chmod -x README-turbo.txt
# Remove unwanted files
rm -f %{buildroot}%{_libdir}/lib{,turbo}jpeg.la
rm %{buildroot}%{_bindir}/*
rm %{buildroot}%{_mandir}/man1/*
# libjpegturbo is provided with libjpeg-turbo.spec yet
rm %{buildroot}%{_includedir}/turbojpeg.h
rm %{buildroot}%{_libdir}/libturbojpeg.so*
# Remove docs, we'll select docs manually
rm -rf %{buildroot}%{_datadir}/doc/

%post -n libjpeg%{major} -p /sbin/ldconfig

%postun -n libjpeg%{major} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc README README-turbo.txt change.log ChangeLog.txt
%doc usage.txt wizard.txt

%files -n libjpeg%{major}
%defattr(-,root,root)
%{_libdir}/libjpeg.so.%{major}
%{_libdir}/libjpeg.so.%{libver}

%files -n libjpeg%{major}-devel
%defattr(-,root,root)
%{_includedir}/*.h
%{_libdir}/libjpeg.so
%doc coderules.txt jconfig.txt libjpeg.txt structure.txt example.c

%changelog
* Thu Nov 27 2014 pgajdos@suse.com
- security update CVE-2014-9092 [bnc#906761]
  * added libjpeg-turbo-CVE-2014-9092.patch
* Mon Mar 31 2014 pgajdos@suse.com
-  update to 1.3.1:
  * Fixed a bug whereby attempting to encode a progressive JPEG
    with arithmetic entropy coding (by passing arguments of
  - progressive -arithmetic to cjpeg or jpegtran, for instance)
    would result in an error, "Requested feature was omitted at
    compile time".
  * Fixed a couple of issues whereby malformed JPEG images would
    cause libjpeg-turbo to use uninitialized memory during
    decompression.
  * Fixed an error ("Buffer passed to JPEG library is too small")
    that occurred when calling the TurboJPEG YUV encoding function
    with a very small (< 5x5) source image, and added a unit test
    to check for this error.
  * etc. see ChangeLog.txt
* Tue Sep 10 2013 pgajdos@suse.com
- update do 1.3.0:
  * Fixed a Huffman encoder bug that prevented I/O suspension from
    working properly.
  * Added support for additional scaling factors (3/8, 5/8, 3/4,
    7/8, 9/8, 5/4, 11/8, 3/2, 13/8, 7/4, 15/8, and 2) when
    decompressing.  Note that the IDCT will not be SIMD-accelerated
    when using any of these new scaling factors.
  * The tjDecompressToYUV() function now supports the TJFLAG_FASTDCT
    flag.
  * cjpeg can now be used to generate JPEG files with the RGB
    colorspace (feature ported from jpeg-8d.)
  * etc. see ChangeLog.txt
* Fri Jun 14 2013 pgajdos@suse.com
- by change from Wed Mar  6 11:19:02 UTC 2013, libjpeg62-turbo
  do not provide any binaries, so it should not provide jpeg
* Mon May 27 2013 crrodriguez@opensuse.org
- Build with full RELRO as this library is exposed to·
  possible malicious images.
* Wed Mar  6 2013 pgajdos@suse.com
- remove
  %%{_bindir}/*
  %%doc %%{_mandir}/man1/*
  https://bugzilla.novell.com/show_bug.cgi?id=807183#c14
* Wed Mar  6 2013 pgajdos@suse.com
- libjpeg62-turbo package created [bnc#807183]
* Mon Aug 13 2012 dmueller@suse.com
- selfconflicts are not possible, remove it
* Mon Jul 23 2012 pgajdos@suse.com
- Update to version 1.2.1:
  * fixed heap overflow [bnc#771791]
* Thu Mar 22 2012 idonmez@suse.com
- Update to version 1.2.0
  * Fixed out-of-bounds read in SSE2 SIMD code
  * Added a compile-time macro (LIBJPEG_TURBO_VERSION) that can
    be used to check the version of libjpeg-turbo against which
    an application was compiled.
  * Added new RGBA/BGRA/ABGR/ARGB colorspace extension constants
  * libjpeg-turbo will now correctly decompress erroneous
    CMYK/YCCK JPEGs whose K component is assigned a component ID
    of 1 instead of 4.
  * Added SIMD routines for RGB-to-grayscale color conversion
  * Improved the performance of the C color conversion routines
  * Added a function to the TurboJPEG API that performs lossless
    transforms.
  * Added support for 4:4:0 (transposed 4:2:2) subsampling
* Sat Nov 19 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sat Nov 12 2011 crrodriguez@opensuse.org
- Open all file descriptors with O_CLOEXEC, extended description
  in the patch file.
* Thu May 19 2011 pgajdos@suse.cz
- updated to 1.1.1:
  * Fixed a 1-pixel error in row 0, column 21 of the luminance
    plane generated by tjEncodeYUV().
  * libjpeg-turbo's accelerated Huffman decoder previously
    ignored unexpected markers found in the middle of the
    JPEG data stream during decompression. It will now
    hand off decoding of a particular block to the unaccelerated
    Huffman decoder if an unexpected marker is found, so that
    the unaccelerated Huffman decoder can generate an appropriate
    warning.
  * Fixed a bug in jpeg_read_coefficients() whereby it would
    not initialize cinfo->image_width and cinfo->image_height
    if libjpeg v7 or v8 emulation was enabled. This specifically
    caused the jpegoptim program to fail if it was linked against
    a version of libjpeg-turbo that was built with libjpeg v7 or
    v8 emulation.
  * Eliminated excessive I/O overhead that occurred when reading
    BMP files in cjpeg.
  * 
* Thu Mar  3 2011 pgajdos@suse.cz
- updated to 1.1.0:
  * Added further protections against invalid Huffman codes.
  * Added an extended version of tjDecompressHeader().
  * Added arithmetic encoding and decoding support.
  * TurboJPEG/OSS can now compress from/decompress to
    grayscale bitmaps.
  * Added emulation of the libjpeg v7 and v8 APIs and ABIs.
  * Added two new TurboJPEG API functions, tjEncodeYUV() and
    tjDecompressToYUV().
  * The TurboJPEG dynamic library now uses versioned symbols.
  * Fixed visual artifacts in grayscale JPEG compression
    caused by a typo in the RGB-to-chrominance lookup tables.
- see ChangeLog.txt for details.
- removed upstreamed jpegtran.patch and rh639672.patch
* Tue Dec 14 2010 pgajdos@suse.cz
- spec file cleanup
* Fri Dec 10 2010 pgajdos@novell.com
- this jpeg version will be the default to the prejudice of jpeg8
  from now on
* Sun Nov  7 2010 prusnak@opensuse.org
- created package based on Fedora one (v 1.0.1)
